@@ -4,7 +4,6 @@ import datetime
 import functools
 import json
 import logging
-import time
 import uuid
 
 from google import auth
@@ -33,15 +32,15 @@ BATCH_SETTINGS = pubsub_v1.types.BatchSettings(max_bytes=10 * 1000 * 1000, max_l
 
 class Service(CoolNameable):
     """A Twined service that can be used in two modes:
-    * As a server accepting questions (input values and manifests), running them through its app, and responding to the
-    requesting service with the results of the analysis.
-    * As a requester of answers from another Service in the above mode.
+    - As a child accepting questions (input values and manifests) from parents, running them through its app, and
+      responding with the results of the analysis
+    - As a parent asking questions to children in the above mode
 
     Services communicate entirely via Google Pub/Sub and can ask and/or respond to questions from any other Service that
     has a corresponding topic on Google Pub/Sub.
 
     :param octue.resources.service_backends.ServiceBackend backend: the object representing the type of backend the service uses
-    :param str|None service_id: a string UUID optionally preceded by the octue services namespace "octue.services."
+    :param str|None service_id: a unique ID to give to the service (any string); a UUID is generated if none is given
     :param callable|None run_function: the function the service should run when it is called
     :return None:
     """
@@ -57,11 +56,12 @@ class Service(CoolNameable):
             else:
                 self.id = f"{OCTUE_NAMESPACE}.{service_id}"
 
+            self.id = self._clean_service_id(self.id)
+
         self.backend = backend
         self.run_function = run_function
         self._credentials = auth.default()[0]
         self.publisher = pubsub_v1.PublisherClient(credentials=self._credentials, batch_settings=BATCH_SETTINGS)
-        self._current_question = None
         super().__init__(*args, **kwargs)
 
     def __repr__(self):
@@ -75,7 +75,7 @@ class Service(CoolNameable):
         :param bool delete_topic_and_subscription_on_exit: if `True`, delete the service's topic and subscription on exit
         :return None:
         """
-        logger.info("Starting service with ID %r.", self.id)
+        logger.info("Starting %r.", self)
 
         topic = Topic(name=self.id, namespace=OCTUE_NAMESPACE, service=self)
         subscriber = pubsub_v1.SubscriberClient(credentials=self._credentials)
@@ -119,11 +119,11 @@ class Service(CoolNameable):
 
     def answer(self, question, answer_topic=None, timeout=30):
         """Answer a question (i.e. run the Service's app to analyse the given data, and return the output values to the
-        asker). Answers are published to a topic whose name is generated from the UUID sent with the question, and are
+        parent). Answers are published to a topic whose name is generated from the UUID sent with the question, and are
         in the format specified in the Service's Twine file.
 
         :param dict|Message question:
-        :param octue.cloud.pub_sub.topic.Topic|None answer_topic: provide if messages need to be sent to the asker from outside the service (e.g. in octue.cloud.deployment.google.cloud_run.flask_app)
+        :param octue.cloud.pub_sub.topic.Topic|None answer_topic: provide if messages need to be sent to the parent from outside the service (e.g. in octue.cloud.deployment.google.cloud_run.flask_app)
         :param float|None timeout: time in seconds to keep retrying sending of the answer once it has been calculated
         :raise Exception: if any exception arises during running analysis and sending its results
         :return None:
@@ -165,10 +165,10 @@ class Service(CoolNameable):
                 retry=retry.Retry(deadline=timeout),
             )
             topic.messages_published += 1
-            logger.info("%r responded to question %r.", self, question_uuid)
+            logger.info("%r answered question %r.", self, question_uuid)
 
         except BaseException as error:  # noqa
-            self.send_exception_to_asker(topic, timeout)
+            self.send_exception(topic, timeout)
             raise error
 
     def instantiate_answer_topic(self, question_uuid, service_id=None):
@@ -208,7 +208,7 @@ class Service(CoolNameable):
         :param str|None question_uuid: the UUID to use for the question if a specific one is needed; a UUID is generated if not
         :param str|None push_endpoint: if answers to the question should be pushed to an endpoint, provide its URL here; if they should be pulled, leave this as `None`
         :param float|None timeout: time in seconds to keep retrying sending the question
-        :return (octue.cloud.pub_sub.subscription.Subscription, str): the response subscription and question UUID
+        :return (octue.cloud.pub_sub.subscription.Subscription, str): the answer subscription and question UUID
         """
         if not allow_local_files:
             if (input_manifest is not None) and (not input_manifest.all_datasets_are_in_cloud):
@@ -218,31 +218,27 @@ class Service(CoolNameable):
                     "the new cloud locations."
                 )
 
+        unlinted_service_id = service_id
+        service_id = self._clean_service_id(service_id)
         question_topic = Topic(name=service_id, namespace=OCTUE_NAMESPACE, service=self)
 
         if not question_topic.exists(timeout=timeout):
-            raise octue.exceptions.ServiceNotFound(f"Service with ID {service_id!r} cannot be found.")
-
-        # If a question UUID is given, this is probably a retry so allow the question topic to already exist.
-        if question_uuid:
-            allow_existing_topic = True
-        else:
-            allow_existing_topic = False
+            raise octue.exceptions.ServiceNotFound(f"Service with ID {unlinted_service_id!r} cannot be found.")
 
         question_uuid = question_uuid or str(uuid.uuid4())
 
-        response_topic = self.instantiate_answer_topic(question_uuid, service_id)
-        response_topic.create(allow_existing=allow_existing_topic)
+        answer_topic = self.instantiate_answer_topic(question_uuid, service_id)
+        answer_topic.create(allow_existing=False)
 
-        response_subscription = Subscription(
-            name=response_topic.name,
-            topic=response_topic,
+        answer_subscription = Subscription(
+            name=answer_topic.name,
+            topic=answer_topic,
             namespace=OCTUE_NAMESPACE,
             project_name=self.backend.project_name,
             subscriber=pubsub_v1.SubscriberClient(credentials=self._credentials),
             push_endpoint=push_endpoint,
         )
-        response_subscription.create(allow_existing=True)
+        answer_subscription.create(allow_existing=True)
 
         serialised_input_manifest = None
         if input_manifest is not None:
@@ -256,19 +252,8 @@ class Service(CoolNameable):
             retry=retry.Retry(deadline=timeout),
         )
 
-        # Keep a record of the question asked in case it needs to be retried.
-        self._current_question = {
-            "service_id": service_id,
-            "input_values": input_values,
-            "input_manifest": input_manifest,
-            "question_uuid": question_uuid,
-            "subscribe_to_logs": subscribe_to_logs,
-            "allow_local_files": allow_local_files,
-            "timeout": timeout,
-        }
-
-        logger.info("%r asked a question %r to service %r.", self, question_uuid, service_id)
-        return response_subscription, question_uuid
+        logger.info("%r asked a question %r to service %r.", self, question_uuid, unlinted_service_id)
+        return answer_subscription, question_uuid
 
     def wait_for_answer(
         self,
@@ -276,8 +261,7 @@ class Service(CoolNameable):
         handle_monitor_message=None,
         service_name="REMOTE",
         timeout=60,
-        delivery_acknowledgement_timeout=30,
-        retry_interval=5,
+        delivery_acknowledgement_timeout=120,
     ):
         """Wait for an answer to a question on the given subscription, deleting the subscription and its topic once
         the answer is received.
@@ -286,9 +270,9 @@ class Service(CoolNameable):
         :param callable|None handle_monitor_message: a function to handle monitor messages (e.g. send them to an endpoint for plotting or displaying) - this function should take a single JSON-compatible python primitive as an argument (note that this could be an array or object)
         :param str service_name: an arbitrary name to refer to the service subscribed to by (used for labelling its remote log messages)
         :param float|None timeout: how long in seconds to wait for an answer before raising a `TimeoutError`
-        :param float delivery_acknowledgement_timeout: how long in seconds to wait for a delivery acknowledgement before resending the question
-        :param float retry_interval: the time in seconds to wait between question retries
+        :param float delivery_acknowledgement_timeout: how long in seconds to wait for a delivery acknowledgement before aborting
         :raise TimeoutError: if the timeout is exceeded
+        :raise octue.exceptions.QuestionNotDelivered: if a delivery acknowledgement is not received in time
         :return dict: dictionary containing the keys "output_values" and "output_manifest"
         """
         if subscription.is_push_subscription:
@@ -306,32 +290,50 @@ class Service(CoolNameable):
         )
 
         try:
-            # Retry sending the question until the overall timeout is reached.
-            while not message_handler.received_delivery_acknowledgement:
-
-                try:
-                    return message_handler.handle_messages(
-                        timeout=timeout,
-                        delivery_acknowledgement_timeout=delivery_acknowledgement_timeout,
-                    )
-
-                except octue.exceptions.QuestionNotDelivered:
-                    logger.info(
-                        "%r: No acknowledgement of question delivery after %fs - resending in %fs.",
-                        self,
-                        delivery_acknowledgement_timeout,
-                        retry_interval,
-                    )
-
-                    time.sleep(retry_interval)
-                    self.ask(**self._current_question)
-
+            return message_handler.handle_messages(
+                timeout=timeout,
+                delivery_acknowledgement_timeout=delivery_acknowledgement_timeout,
+            )
         finally:
             subscription.delete()
             subscriber.close()
 
+    def send_exception(self, topic, timeout=30):
+        """Serialise and send the exception being handled to the parent.
+
+        :param octue.cloud.pub_sub.topic.Topic topic:
+        :param float|None timeout: time in seconds to keep retrying sending of the exception
+        :return None:
+        """
+        exception = convert_exception_to_primitives()
+        exception_message = f"Error in {self!r}: {exception['message']}"
+
+        self.publisher.publish(
+            topic=topic.path,
+            data=json.dumps(
+                {
+                    "type": "exception",
+                    "exception_type": exception["type"],
+                    "exception_message": exception_message,
+                    "traceback": exception["traceback"],
+                    "message_number": topic.messages_published,
+                }
+            ).encode(),
+            retry=retry.Retry(deadline=timeout),
+        )
+
+        topic.messages_published += 1
+
+    def _clean_service_id(self, service_id):
+        """Replace forward slashes in the given service ID with dots.
+
+        :param str service_id: the raw service ID
+        :return str: the cleaned service ID.
+        """
+        return service_id.replace("/", ".")
+
     def _send_delivery_acknowledgment(self, topic, timeout=30):
-        """Send an acknowledgement of question delivery to the asker.
+        """Send an acknowledgement of question delivery to the parent.
 
         :param octue.cloud.pub_sub.topic.Topic topic: topic to send acknowledgement to
         :param float timeout: time in seconds after which to give up sending
@@ -354,7 +356,7 @@ class Service(CoolNameable):
         topic.messages_published += 1
 
     def _send_monitor_message(self, data, topic, timeout=30):
-        """Send a monitor message to the asker.
+        """Send a monitor message to the parent.
 
         :param any data: the data to send as a monitor message
         :param octue.cloud.pub_sub.topic.Topic topic: the topic to send the message to
@@ -377,32 +379,6 @@ class Service(CoolNameable):
 
         topic.messages_published += 1
 
-    def send_exception_to_asker(self, topic, timeout=30):
-        """Serialise and send the exception being handled to the asker.
-
-        :param octue.cloud.pub_sub.topic.Topic topic:
-        :param float|None timeout: time in seconds to keep retrying sending of the exception
-        :return None:
-        """
-        exception = convert_exception_to_primitives()
-        exception_message = f"Error in {self!r}: {exception['message']}"
-
-        self.publisher.publish(
-            topic=topic.path,
-            data=json.dumps(
-                {
-                    "type": "exception",
-                    "exception_type": exception["type"],
-                    "exception_message": exception_message,
-                    "traceback": exception["traceback"],
-                    "message_number": topic.messages_published,
-                }
-            ).encode(),
-            retry=retry.Retry(deadline=timeout),
-        )
-
-        topic.messages_published += 1
-
     def _parse_question(self, question):
         """Parse a question in the Google Cloud Pub/Sub or Google Cloud Run format.
 
