@@ -12,19 +12,31 @@ class Child:
     makes the asking of questions more intuitive for Scientists and allows easier selection of backends.
 
     :param str name: an arbitrary name to refer to the child by (used to access it in Analysis instances and give context to log messages forwarded from the child)
-    :param str id: the UUID of the child service
+    :param str id: the ID of the child service
     :param dict backend: must include the key "name" with a value of the name of the type of backend e.g. GCPPubSubBackend and key-value pairs for any other parameters the chosen backend expects
+    :param str|None internal_service_name: the name to give to the internal service used to ask questions to the child
     :return None:
     """
 
-    def __init__(self, name, id, backend):
+    def __init__(self, name, id, backend, internal_service_name=None):
         self.name = name
         self.id = id
 
         backend = copy.deepcopy(backend)
         backend_type_name = backend.pop("name")
         backend = service_backends.get_backend(backend_type_name)(**backend)
-        self._service = BACKEND_TO_SERVICE_MAPPING[backend_type_name](name=f"{self.name}-parent", backend=backend)
+
+        self._service = BACKEND_TO_SERVICE_MAPPING[backend_type_name](
+            name=internal_service_name or f"{self.name}-parent",
+            backend=backend,
+        )
+
+    def __repr__(self):
+        """Represent the child as a string.
+
+        :return str:
+        """
+        return f"<{type(self).__name__}({self.name!r})>"
 
     def ask(
         self,
