@@ -1,13 +1,10 @@
 import concurrent.futures
 import copy
 import json
-import warnings
 
-import octue.migrations.manifest
 from octue.cloud import storage
 from octue.cloud.storage import GoogleCloudStorageClient
 from octue.exceptions import InvalidInputException
-from octue.migrations.cloud_storage import translate_bucket_name_and_path_in_bucket_to_cloud_path
 from octue.mixins import Hashable, Identifiable, Metadata, Serialisable
 from octue.resources.dataset import Dataset
 
@@ -16,9 +13,9 @@ class Manifest(Serialisable, Identifiable, Hashable, Metadata):
     """A representation of a manifest, which can contain multiple datasets This is used to manage all files coming into
     (or leaving), a data service for an analysis at the configuration, input or output stage.
 
-    :param str|None id: the UUID of the manifest (a UUID is generated if one isn't given)
-    :param str|None path: the path the manifest exists at (defaults to the current working directory)
     :param dict(str, octue.resources.dataset.Dataset|dict|str)|None datasets: a mapping of dataset names to `Dataset` instances, serialised datasets, or paths to datasets
+    :param str|None id: the UUID of the manifest (a UUID is generated if one isn't given)
+    :param str|None name: an optional name to give to the manifest
     :return None:
     """
 
@@ -28,28 +25,22 @@ class Manifest(Serialisable, Identifiable, Hashable, Metadata):
     # Paths to datasets are added to the serialisation in `Manifest.to_primitive`.
     _SERIALISE_FIELDS = (*_METADATA_ATTRIBUTES, "name")
 
-    def __init__(self, id=None, name=None, datasets=None, **kwargs):
-        if isinstance(datasets, list):
-            datasets = octue.migrations.manifest.translate_datasets_list_to_dictionary(datasets, kwargs.get("keys"))
-
+    def __init__(self, datasets=None, id=None, name=None):
         super().__init__(id=id, name=name)
         self.datasets = self._instantiate_datasets(datasets or {})
 
     @classmethod
-    def from_cloud(cls, cloud_path=None, bucket_name=None, path_to_manifest_file=None):
+    def from_cloud(cls, cloud_path):
         """Instantiate a Manifest from Google Cloud storage.
 
-        :param str|None cloud_path: full path to manifest in cloud storage (e.g. `gs://bucket_name/path/to/manifest.json`)
+        :param str cloud_path: full path to manifest in cloud storage (e.g. `gs://bucket_name/path/to/manifest.json`)
         :return Dataset:
         """
-        if not cloud_path:
-            cloud_path = translate_bucket_name_and_path_in_bucket_to_cloud_path(bucket_name, path_to_manifest_file)
-
         serialised_manifest = json.loads(GoogleCloudStorageClient().download_as_string(cloud_path))
 
         return Manifest(
             id=serialised_manifest["id"],
-            datasets={key: Dataset.from_cloud(dataset) for key, dataset in serialised_manifest["datasets"].items()},
+            datasets={key: Dataset(path=dataset) for key, dataset in serialised_manifest["datasets"].items()},
         )
 
     @property
@@ -60,24 +51,12 @@ class Manifest(Serialisable, Identifiable, Hashable, Metadata):
         """
         return all(dataset.all_files_are_in_cloud for dataset in self.datasets.values())
 
-    def to_cloud(self, cloud_path=None, bucket_name=None, path_to_manifest_file=None, store_datasets=None):
+    def to_cloud(self, cloud_path):
         """Upload a manifest to a cloud location, optionally uploading its datasets into the same directory.
 
-        :param str|None cloud_path: full path to cloud storage location to store manifest at (e.g. `gs://bucket_name/path/to/manifest.json`)
+        :param str cloud_path: full path to cloud storage location to store manifest at (e.g. `gs://bucket_name/path/to/manifest.json`)
         :return None:
         """
-        if store_datasets:
-            warnings.warn(
-                message=(
-                    "The `store_datasets` parameter is no longer available - please call the `to_cloud` method on any "
-                    "datasets you wish to upload to the cloud separately."
-                ),
-                category=DeprecationWarning,
-            )
-
-        if not cloud_path:
-            cloud_path = translate_bucket_name_and_path_in_bucket_to_cloud_path(bucket_name, path_to_manifest_file)
-
         GoogleCloudStorageClient().upload_from_string(string=json.dumps(self.to_primitive()), cloud_path=cloud_path)
 
     def get_dataset(self, key):
@@ -153,15 +132,11 @@ class Manifest(Serialisable, Identifiable, Hashable, Metadata):
 
         # If `dataset` is just a path to a dataset:
         if isinstance(dataset, str):
-
-            if storage.path.is_cloud_path(dataset):
-                return (key, Dataset.from_cloud(cloud_path=dataset, recursive=True))
-
-            return (key, Dataset.from_local_directory(path_to_directory=dataset, recursive=True))
+            return (key, Dataset(path=dataset, recursive=True))
 
         # If `dataset` is a dictionary including a "path" key:
         if storage.path.is_cloud_path(dataset["path"]):
-            return (key, Dataset.from_cloud(cloud_path=dataset["path"], recursive=True))
+            return (key, Dataset(path=dataset["path"], recursive=True))
 
         return (key, Dataset(**dataset))
 
